/* File:        $Id: ExceptionUtilsTester.java 1338 2010-03-17 15:27:53Z svc $
 * Revision:    $Revision: 1338 $
 * Author:      $Author: svc $
 * Date:        $Date: 2010-03-17 16:27:53 +0100 (Wed, 17 Mar 2010) $
 *
 * The Netarchive Suite - Software to harvest and preserve websites
 * Copyright 2004-2010 Det Kongelige Bibliotek and Statsbiblioteket, Denmark
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package dk.netarkivet.common.utils;

import java.sql.SQLException;

import junit.framework.TestCase;

import dk.netarkivet.common.exceptions.ArgumentNotValid;
import dk.netarkivet.testutils.ClassAsserts;
import dk.netarkivet.testutils.StringAsserts;

/**
 * Unit tests for the ExceptionUtils class.
 */
public class ExceptionUtilsTester extends TestCase {
    public ExceptionUtilsTester(String s) {
        super(s);
    }

    public void setUp() {
    }

    public void tearDown() {
    }

    /** Test that this utility class cannot be instantiated. */
    public void testExceptionUtils() {
        ClassAsserts.assertPrivateConstructor(ExceptionUtils.class);
    }

    /** Test that exceptions are printed including all stacktraces,
     * and that nul exceptions are turned into 'null\n'. */
    public void testGetStackTrace() throws Exception {
        assertEquals(
                "Null exceptions should simply return 'null' and a linebreak",
                "null\n", ExceptionUtils.getStackTrace(null));
        String exceptionMessage = "Test";
        ArgumentNotValid cause = new ArgumentNotValid(exceptionMessage);
        ArgumentNotValid throwable = new ArgumentNotValid(exceptionMessage,
                                                          cause);
        String result = ExceptionUtils.getStackTrace(
                throwable);
        StringAsserts.assertStringContains("Should contain the exception",
                                           ArgumentNotValid.class.getName(),
                                           result);
        StringAsserts.assertStringContains("Should contain the exception msg",
                                           exceptionMessage,
                                           result);
        StringAsserts.assertStringContains("Should contain the stacktrace",
                                           "testGetStackTrace",
                                           result);
        StringAsserts.assertStringContains("Should contain the stacktrace",
                                           "ExceptionUtilsTester",
                                           result);
        StringAsserts.assertStringContains("Should contain the cause",
                                           "Caused by:",
                                           result);
    }
    
    /**
     * this test confirms that the message generated by getSQLExceptionCause() contains
     * all the information in the original SQLException
     */
    public void testGetSQLExceptionCause() {
        SQLException ex1 = new SQLException("reason1", "state1", 101);
        SQLException ex2 = new SQLException("reason2", "state2", 102);
        SQLException ex3 = new SQLException("reason3", "state3", 103);
        ex1.setNextException(ex2);
        ex2.setNextException(ex3);
        String message = dk.netarkivet.common.utils.ExceptionUtils.getSQLExceptionCause(ex1);
        System.out.println(message);
        StringAsserts.assertStringContains("Compound exception should contain "
                                           + "references to all three "
                   + "reasons, states, and codes", message, "reason1",
                     "reason2", "reason3", "state1", "state2", "state3",
                     "101", "102", "103");
    }

}